#
# spec file for package zynaddsubfx
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           zynaddsubfx
BuildRequires:  alsa-devel
BuildRequires:  cmake
BuildRequires:  dssi
BuildRequires:  dssi-devel
BuildRequires:  fftw3-devel
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  lash-devel
BuildRequires:  libjack-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblo-devel
BuildRequires:  libpng-devel
BuildRequires:  mxml-devel
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
BuildRequires:  zlib-devel
# for lv2 and vst plugin UIs
%if 0%{suse_version} > 1320 || (0%{?is_opensuse} && 0%{?sle_version} == 120200)
BuildRequires:  non-ntk-devel
%endif

Provides:       ZynAddSubFX = %{version}
Obsoletes:      ZynAddSubFX < %{version}
Version:        2.5.4
Release:        2.10
Summary:        A Real-Time Software Synthesizer for Linux
License:        GPL-2.0
Group:          Productivity/Multimedia/Sound/Midi
Url:            http://zynaddsubfx.sourceforge.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %{name}-%{version}.tar.bz2
Patch0:         zynaddsubfx-buildflags.patch

%description
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

%package common
Summary:        Common files for ZynAddSubFX synthesizers
Group:          Productivity/Multimedia/Sound/Midi
Provides:       ZynAddSubFX-common = %{version}
Obsoletes:      ZynAddSubFX-common < %{version}
Conflicts:      ZynAddSubFX-common < %{version}
BuildArch:      noarch

%description common
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

This package includes the common files needed by the implementations of the
synthesizer.

%package dssi
Summary:        Real-time software synthesizer for DSSI
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name}-common = %{version}-%{release}
Requires:       dssi

%description dssi
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

This package includes the DSSI implementation of the synthesizer.

%package lv2
Summary:        Real-time software synthesizer for DSSI
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name}-common = %{version}-%{release}

%description lv2
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

This package includes the LV2 implementation of the synthesizer.

%package vst
Summary:        Real-time software synthesizer for DSSI
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name}-common = %{version}-%{release}

%description vst
zynaddsubfx is a many-featured real-time software synthesizer for
Linux.	Features include polyphony and multitimbrel and microtonal
capabilities. It includes randomness of some parameters, which can make
warm sounds, like analog synthesizers.	This program has system and
insertion effects, too.

This package includes the VST implementation of the synthesizer.

%prep
%setup -q
%patch0 -p1

%build
%cmake \
      -DDefaultOutput=jack -DCMAKE_CXX_FLAGS=-std=c++11\
%ifarch %{ix86} x86_64
      -DX86Build=ON \
%endif
      -DPluginLibDir:STRING=%{_lib}

make %{?_smp_mflags}

%install
make -C build DESTDIR=%{buildroot} install
%suse_update_desktop_file -r %{name}-alsa AudioVideo Music
%suse_update_desktop_file -r %{name}-jack AudioVideo Music
mkdir -p $RPM_BUILD_ROOT%{_datadir}/zynaddsubfx
cp -a instruments/examples instruments/banks $RPM_BUILD_ROOT%{_datadir}/zynaddsubfx

# We are including these in the common package below
rm -fr %{buildroot}%{_datadir}/doc/%{name}/

%files
%defattr(-, root, root)
%doc AUTHORS.txt ChangeLog COPYING HISTORY.txt README.adoc
%{_bindir}/*
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/pixmaps/zynaddsubfx.svg

%files common
%defattr(-, root, root)
%doc AUTHORS.txt ChangeLog COPYING HISTORY.txt README.adoc
%{_datadir}/%{name}/

%files dssi
%defattr(-, root, root)
%{_libdir}/dssi/

%files lv2
%defattr(-, root, root)
%{_libdir}/lv2/

%files vst
%defattr(-, root, root)
%{_libdir}/vst/

%changelog
* Mon Aug 15 2016 davejplater@gmail.com
- Allow Leap:42.2 build to use non-ntk
* Thu Jun 30 2016 jengelh@inai.de
- Trim filelist, implicit parameters, stick to SUSE changelog
  format.
* Wed Jun 29 2016 davejplater@gmail.com
- Update to 2.5.4
- Moved plugins to correct library arch directory.
- Rebased zynaddsubfx-buildflags.patch
- Upstream changes:
  * Add realtime automation for subnote parameters
  * Add FLTK UI for LV2 plugins
  * Add support for '~' in bank paths
  * Fix VST crashes
  * Fix VST loading issues
  * Fix Microtonal copy/paste
  * Fix GCC 5.3.0 build issues
  * Fix autosave disable flag
  * Fix license headers
  * Fix plugin library directory
  * Fix uninitialized filter bug in subnote
  * Fix broken instrument send
* Wed Feb 10 2016 edogawa@aon.at
- update to version 2.5.3
  * updated zynaddsubfx-buildflags.patch
  * added subpackages for the new lv2 and vst plugin variants
  * Add autosave - Just in case of the rare crash, this can be a lifesaver
  * Add realtime filter parameter updates - For smoother, wilder filter tweaking
  * Add LFO random mode - adds sample and hold module integrated to the LFO,
    great for classic bleep-blop computer sounds (and a hundred other things)
  * Add more controls to DSSI plugin - For more knob turning sonic
    automation-exploration in DSSI plugin hosts
  * Add fixed frequency modulators - Easier FM operations
  * Add more reset states to knobs/sliders - double click will put it back to
    the default state, so you don’t need to be afraid of turning that knob, you
    can always go back.
  * dd PWM mod - Sweet sweeping from nasally to full bodied square waves
  * Fix Microtonal UI - if you do microtonal music, this is a huge deal!
  * Fix 'Add Bank' - easier organization for all your patches
  * Fix sustain bugs in 2.5.x series - So you can keep your feet below your
    keyboard to play more notes
  * Fix mem pool exhaustion bug - a boon to stability
  * Fix PADnote and Oscilgen copy/paste - for quicker sound design
  * Fix Midi unlearn - If you want to map that knob to something else...
  * Other miscellaneous bug fixes
  * New Presets in the 'olivers-other' bank.
* Sun Nov 22 2015 someuniquename@gmail.com
- Update to version 2.5.2
  * Add MIDI-Learn serialization
  * Add pink noise source
  * Restore mousewheel functionality
  * Restore bank LSB/MSB MIDI support
  * Improve tip windows
  * Improve oscdoc output
  * Restore External Oscillator/Modulator functionality
  * Remove remaining globals
  * Fix UI connection bugs
  * Added shortcuts on edit buttons
  * Other miscellaneous bug fixes
- Changes from version 2.5.0
  - Release 2.5.1 (4 Jul 2015)
    Add Colorized CMake Configuration
    Add PID option for jack
    Add OSC port option
    Add MIDI unlearn
    Add External UI Compilation
    Add Split Pitchbend
    Fix No Install NTK Build
    Fix Linker Issues
    Fix Presets/Copy/Paste
    Fix JACK Samplerate Check When JACK Isn't Running
    Remove Dump
    Remove Some Globals synth/uToB/bToU/etc
    Adjust BankUI Ascetic
    Other Misc Bug Fixes
- Changes from version 2.4.4
  - Release 2.5.0 (25 Feb 2015)
    Add Rtosc
    Add tlsf RT Memory Allocator
    Add --dump-oscdoc Flag
    Add OSC API
    Add Jack-OSC Support
    Add MIDI Learn
    Add Undo/Redo
    Add Multi-Out JACK Engine
    Add Multi-Out OSS Engine
    Add Top Level Window Icon
    Add OSS env Vars MIDI_DEVICE/DSP_DEVICE
    Add OSC port/PID file
    Remove Master::mutex
    Remove Almost All RT Unsafe Actions
    Disable (temporarily) DSSI
    Disable (temporarily) Copy/Paste
    Massive Internal Refactoring
* Tue Feb 17 2015 p.drouand@gmail.com
- Fix "Conflicts"
* Mon Feb 16 2015 p.drouand@gmail.com
- Fix license; GPL-2.0 only
* Mon Feb 16 2015 p.drouand@gmail.com
- Do zynaddsubfx conflict with ZynAddSubFx
* Sat Feb 14 2015 p.drouand@gmail.com
- Add zynaddsubfx-fix-GPL-license.patch; fix licensing conflict
  between GPL; There is an incompatibility here as this package
  mixes GPL-2.0 (only) with GPL-3.0 code:
  src/Nio/WavEngine.cpp (and other files) is GPL-2.0
  src/Nio/AlsaEngine.cpp and src/Nio/JackEngine.cpp is GPL-3.0+
* Mon Dec 15 2014 p.drouand@gmail.com
- ZynAddSubFx has been renamed by upstream in zynaddsubfx;
  this package provides/obsoletes ZynAddSubFx
- Split out data files into his own subpackage
- Split out the dssi module
* Sat Dec 13 2014 p.drouand@gmail.com
- Update to version 2.4.4
  + Add UI Mousewheel Support
  + Add Spectral Adjust Parameter Rescaling
  + Add Subnote filter smoothing
  + Add Unison derandomization options
  + Add NSM import/export
  + Add NTK UI compatiability
  + (re)Add OSX Support
  + Enhance performance of ADnote and SUBnote
  + Enhance Installer
  + Fix JACK2 specific segfault
  + Fix possible DSSI specific segfaults
  + Fix Unison Regressions
  + Documentation additions
  + Misc bug fixes
- Changes from version 2.4.3
  + Non  +session manager support
  + Midi aftertouch support
  + Documentation additions
  + Somewhat more sane Nio defaults
  + Misc bug fixes
- Changes from version 2.4.2
  + New IO backend support
  + MIDI bank select
  + Spike/Circle waveform
  + Faster subsynth
  + --exec-after-init flag
  + Version information compiled in
  + Misc Bug fixes
- Added patches
  + zynaddsubfx-array-overflow-fix.diff
  + zynaddsubfx-buildflags.patch
* Tue Jul 12 2011 pgajdos@novell.com
- build against fltk 1.3 (taken from git repository)
* Thu Sep 23 2010 davejplater@gmail.com
- Fixed all patches
* Sat Sep 18 2010 davejplater@gmail.com
- Update to version 2.4.1:
  * Adding APhaserand merging into Phaser
  * Azerty layout
  * XML bug fixes
  * Vibrato/Unison additions
  * Reverb rewrite
  * DSSI support enabled
  * other bugfixes
  * code cleanup
* Fri Jul 24 2009 tiwai@suse.de
- updated to version 2.4.0:
  * extended mono functionality
  * legato mode
  * export functionality on PADsynth
  * inclusion of LASH client
  * inclusion of DSSI audio output
  * enabled tooltips for knobs (both description and value tooltips)
  * added support for newer JACK api
  * added quertz support for virtual keyboard
  * started to encorperate cxxtest for unit testing
  * many bugfixes
  * code cleanup
- build DSSI object
* Fri Jan 18 2008 tiwai@suse.de
- fix strncat usage to avoid overflow.
* Thu Apr 26 2007 tiwai@suse.de
- fix buildrequires, use mxml-devel
- fix desktop file, use GenericName
* Mon Feb 26 2007 tiwai@suse.de
- fix array overflow (#247335)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Jul 27 2005 tiwai@suse.de
- updated to version 2.2.1.
* Fri Apr 15 2005 tiwai@suse.de
- updated to version 2.2.0.
- fixed for gcc-4.0.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 2.1.1.
  added desktop file again.
* Wed Sep 15 2004 tiwai@suse.de
- removed desktop file (not working from menu).
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 1.4.3.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop file and icon.
* Fri Jul 18 2003 tiwai@suse.de
- updated to version 1.4.2.
* Wed Jul  2 2003 tiwai@suse.de
- updated to version 1.4.1.
* Thu Mar 27 2003 tiwai@suse.de
- updated to version 1.2.0.
* Fri Feb 14 2003 tiwai@suse.de
- updated to version 1.0.8.
* Fri Feb  7 2003 tiwai@suse.de
- updated to version 1.0.7.
- linked with sfftw correctly now.
- fixed compile warnings.
* Wed Feb  5 2003 tiwai@suse.de
- initial version: 1.0.6.
